@@ -10,7 +10,9 @@
 #' @param verbose Whether to print the message.
 #' Default is `TRUE`.
 #' @param message_type Type of message.
-#' Could be choose one of `"info"`, `"success"`, `"warning"`, `"error"`, and `"running"`.
+#' Could be choose one of `"info"`, `"success"`, `"warning"`, `"error"`, `"running"`, and `"ask"`.
+#' When `"ask"` is used, the function will prompt the user for a Yes/No/Cancel response using [utils::askYesNo],
+#' and returns `TRUE` for Yes, `FALSE` for No, and `NA` for Cancel.
 #' Default is `"info"`.
 #' @param cli_model Whether to use the `cli` package to print the message.
 #' Default is `TRUE`.
@@ -46,7 +48,7 @@
 #' @param timestamp_style Whether to apply the same text styling to the timestamp as the message text.
 #' When `TRUE`, timestamp formatting matches the message;
 #' when `FALSE`, timestamp keeps its default appearance.
-#' Default is `TRUE`.
+#' Default is `FALSE`.
 #' @param plain_text Whether to print only the text content.
 #' When `TRUE`, level, symbol, timestamp, and message type formatting are suppressed,
 #' but color and multiline settings still apply.
@@ -55,7 +57,8 @@
 #' @param .frame The frame to use for error reporting.
 #' Default is `.envir`.
 #'
-#' @return Formated message.
+#' @return
+#' Formated message, or a logical value (`TRUE`/`FALSE`/`NA`) if `message_type = "ask"`.
 #'
 #' @references
 #' \url{https://cli.r-lib.org/articles/index.html}
@@ -286,8 +289,7 @@
 #' log_message(
 #'   "Multi-line message\nwithout timestamp styling",
 #'   text_color = "#669999",
-#'   text_style = c("bold", "italic"),
-#'   timestamp_style = FALSE
+#'   text_style = c("bold", "italic")
 #' )
 #'
 #'
@@ -320,11 +322,19 @@
 #'   z = c(" a", "b  ", "c")
 #' )
 #' log_message("Content:\n", df)
+#'
+#' # interactive prompt
+#' if (interactive()) {
+#'   log_message(
+#'     "Do you want to continue?",
+#'     message_type = "ask"
+#'   )
+#' }
 log_message <- function(
     ...,
     verbose = TRUE,
     message_type = c(
-      "info", "success", "warning", "error", "running"
+      "info", "success", "warning", "error", "running", "ask"
     ),
     cli_model = TRUE,
     level = 1,
@@ -337,18 +347,18 @@ log_message <- function(
     timestamp_format = paste0(
       "[", format(Sys.time(), "%Y-%m-%d %H:%M:%S"), "] "
     ),
-    timestamp_style = TRUE,
+    timestamp_style = FALSE,
     plain_text = FALSE,
     .envir = parent.frame(),
     .frame = .envir) {
   verbose <- get_verbose(verbose)
   message_type <- match.arg(message_type)
-  msg <- .build_message(...)
+  msg <- build_message(...)
 
   if (is.null(.envir) || !is.environment(.envir)) {
     .envir <- parent.frame()
   }
-  caller_call <- .get_caller_call(.frame)
+  caller_call <- get_caller_call(.frame)
 
   if (message_type == "error") {
     cli::cli_abort(msg, call = caller_call, .envir = .envir)
@@ -358,7 +368,7 @@ log_message <- function(
     return(invisible(NULL))
   }
 
-  .validate_params(
+  validate_params(
     level = level,
     symbol = symbol,
     text_color = text_color,
@@ -368,7 +378,27 @@ log_message <- function(
     .frame = .frame
   )
 
-  .output_message(
+  if (message_type == "ask") {
+    output_message(
+      msg = msg,
+      message_type = message_type,
+      cli_model = cli_model,
+      text_color = text_color,
+      back_color = back_color,
+      text_style = text_style,
+      timestamp = timestamp,
+      timestamp_format = timestamp_format,
+      level = level,
+      symbol = symbol,
+      multiline_indent = multiline_indent,
+      timestamp_style = timestamp_style,
+      plain_text = plain_text,
+      .envir = .envir
+    )
+    return(utils::askYesNo(msg = ""))
+  }
+
+  output_message(
     msg = msg,
     message_type = message_type,
     cli_model = cli_model,
@@ -443,7 +473,7 @@ get_verbose <- function(verbose = NULL) {
   verbose
 }
 
-.build_message <- function(...) {
+build_message <- function(...) {
   args <- list(...)
 
   if (length(args) == 0) {
@@ -483,7 +513,7 @@ get_verbose <- function(verbose = NULL) {
   capitalize(msg)
 }
 
-.validate_params <- function(
+validate_params <- function(
     level,
     symbol,
     text_color,
@@ -491,7 +521,7 @@ get_verbose <- function(verbose = NULL) {
     text_style,
     timestamp_style,
     .frame) {
-  caller_call <- .get_caller_call(.frame)
+  caller_call <- get_caller_call(.frame)
 
   if (!is.numeric(level) || length(level) != 1 || level < 1 || level != round(level)) {
     cli::cli_abort(
@@ -509,10 +539,10 @@ get_verbose <- function(verbose = NULL) {
     )
   }
 
-  .validate_color_param <- function(color_value,
-                                    param_name,
-                                    caller_call) {
-    if (!is.null(color_value) && !.check_color(color_value)) {
+  validate_color_param <- function(color_value,
+                                   param_name,
+                                   caller_call) {
+    if (!is.null(color_value) && !check_color(color_value)) {
       error_msg <- paste0(
         "{.arg {param_name}} must be a valid color name, ",
         "hexadecimal color code (e.g., '#000000'), or R color name"
@@ -525,8 +555,8 @@ get_verbose <- function(verbose = NULL) {
     }
   }
 
-  .validate_color_param(text_color, "text_color", caller_call)
-  .validate_color_param(back_color, "back_color", caller_call)
+  validate_color_param(text_color, "text_color", caller_call)
+  validate_color_param(back_color, "back_color", caller_call)
 
   if (!is.null(text_color) && !is.null(back_color) && text_color == back_color) {
     cli::cli_abort(
@@ -558,7 +588,7 @@ get_verbose <- function(verbose = NULL) {
   }
 }
 
-.get_indent_part <- function(symbol, level) {
+get_indent_part <- function(symbol, level) {
   if (symbol != "  ") {
     paste0(paste(rep(symbol, level), collapse = ""), " ")
   } else if (level > 1) {
@@ -568,7 +598,7 @@ get_verbose <- function(verbose = NULL) {
   }
 }
 
-.format_line_with_style <- function(
+format_line_with_style <- function(
     line,
     prefix,
     text_color,
@@ -582,7 +612,7 @@ get_verbose <- function(verbose = NULL) {
 
   if (timestamp_style) {
     full_line <- paste0(prefix, line)
-    .style_formatting(
+    style_formatting(
       msg = full_line,
       text_color = text_color,
       back_color = back_color,
@@ -591,7 +621,7 @@ get_verbose <- function(verbose = NULL) {
       .envir = .envir
     )
   } else {
-    styled_line <- .style_formatting(
+    styled_line <- style_formatting(
       msg = line,
       text_color = text_color,
       back_color = back_color,
@@ -603,7 +633,7 @@ get_verbose <- function(verbose = NULL) {
   }
 }
 
-.output_cli_message <- function(
+output_cli_message <- function(
     message,
     message_type,
     .envir = parent.frame()) {
@@ -617,11 +647,18 @@ get_verbose <- function(verbose = NULL) {
         cli::make_ansi_style("orange")(cli::symbol$circle_dotted), " ", message
       ),
       .envir = .envir
-    )
+    ),
+    "ask" = {
+      magenta_style <- cli::make_ansi_style("magenta")
+      cli::cli_text(
+        paste0(magenta_style("?"), " ", message),
+        .envir = .envir
+      )
+    }
   )
 }
 
-.output_message <- function(
+output_message <- function(
     msg,
     message_type,
     cli_model,
@@ -646,7 +683,7 @@ get_verbose <- function(verbose = NULL) {
     if (length(plain_msg) == 1 && grepl("\n", plain_msg)) {
       lines <- strsplit(plain_msg, "\n", fixed = TRUE)[[1]]
       for (line in lines) {
-        .plain_text_output(
+        plain_text_output(
           text = line,
           cli_model = cli_model,
           text_color = text_color,
@@ -656,7 +693,7 @@ get_verbose <- function(verbose = NULL) {
         )
       }
     } else {
-      .plain_text_output(
+      plain_text_output(
         text = plain_msg,
         cli_model = cli_model,
         text_color = text_color,
@@ -681,10 +718,10 @@ get_verbose <- function(verbose = NULL) {
         } else {
           ""
         }
-        indent_part <- .get_indent_part(symbol, level)
+        indent_part <- get_indent_part(symbol, level)
         prefix <- paste0(timestamp_part, indent_part)
       } else {
-        indent_part <- .get_indent_part(symbol, level)
+        indent_part <- get_indent_part(symbol, level)
         alignment_spaces <- if (timestamp) {
           timestamp_width <- nchar(
             timestamp_format
@@ -696,7 +733,7 @@ get_verbose <- function(verbose = NULL) {
         prefix <- paste0(alignment_spaces, indent_part)
       }
 
-      formatted_line <- .format_line_with_style(
+      formatted_line <- format_line_with_style(
         line = line,
         prefix = prefix,
         text_color = text_color,
@@ -705,7 +742,7 @@ get_verbose <- function(verbose = NULL) {
         timestamp_style = timestamp_style,
         .envir = .envir
       )
-      .output_cli_message(
+      output_cli_message(
         message = formatted_line,
         message_type = message_type,
         .envir = .envir
@@ -720,7 +757,7 @@ get_verbose <- function(verbose = NULL) {
     } else {
       ""
     }
-    indent_part <- .get_indent_part(symbol, level)
+    indent_part <- get_indent_part(symbol, level)
 
     if (symbol != "  ") {
       final_msg <- paste0(
@@ -735,7 +772,7 @@ get_verbose <- function(verbose = NULL) {
 
     if (!is.null(text_color) || !is.null(back_color) || !is.null(text_style)) {
       if (timestamp_style) {
-        final_msg <- .style_formatting(
+        final_msg <- style_formatting(
           msg = final_msg,
           text_color = text_color,
           back_color = back_color,
@@ -744,7 +781,7 @@ get_verbose <- function(verbose = NULL) {
           .envir = .envir
         )
       } else {
-        styled_msg <- .style_formatting(
+        styled_msg <- style_formatting(
           msg = msg,
           text_color = text_color,
           back_color = back_color,
@@ -769,7 +806,7 @@ get_verbose <- function(verbose = NULL) {
       }
     }
 
-    .output_cli_message(
+    output_cli_message(
       message = final_msg,
       message_type = message_type,
       .envir = .envir
@@ -783,7 +820,7 @@ get_verbose <- function(verbose = NULL) {
     )
 
     if (!is.null(text_color) || !is.null(back_color) || !is.null(text_style)) {
-      formatted_msg <- .style_formatting(
+      formatted_msg <- style_formatting(
         msg = formatted_msg,
         text_color = text_color,
         back_color = back_color,
@@ -798,13 +835,14 @@ get_verbose <- function(verbose = NULL) {
       "info" = "",
       "success" = "SUCCESS: ",
       "warning" = "WARNING: ",
-      "running" = "RUNNING: "
+      "running" = "RUNNING: ",
+      "ask" = "? "
     )
     message(paste0(prefix, formatted_msg))
   }
 }
 
-.style_formatting <- function(
+style_formatting <- function(
     msg,
     text_color,
     back_color,
@@ -816,12 +854,12 @@ get_verbose <- function(verbose = NULL) {
   }
 
   if (!is.null(text_color)) {
-    text_fun <- .make_color_style(text_color)
+    text_fun <- make_color_style(text_color)
     msg <- text_fun(msg)
   }
 
   if (!is.null(back_color)) {
-    back_fun <- .make_color_style(back_color, bg = TRUE)
+    back_fun <- make_color_style(back_color, bg = TRUE)
     msg <- back_fun(msg)
   }
 
@@ -845,7 +883,7 @@ get_verbose <- function(verbose = NULL) {
   msg
 }
 
-.plain_text_output <- function(
+plain_text_output <- function(
     text,
     cli_model,
     text_color,
@@ -854,7 +892,7 @@ get_verbose <- function(verbose = NULL) {
     .envir = parent.frame()) {
   if (cli_model) {
     if (!is.null(text_color) || !is.null(back_color) || !is.null(text_style)) {
-      text <- .style_formatting(
+      text <- style_formatting(
         msg = text,
         text_color = text_color,
         back_color = back_color,
@@ -873,7 +911,7 @@ get_verbose <- function(verbose = NULL) {
     )
 
     if (!is.null(text_color) || !is.null(back_color) || !is.null(text_style)) {
-      formatted_text <- .style_formatting(
+      formatted_text <- style_formatting(
         msg = formatted_text,
         text_color = text_color,
         back_color = back_color,
@@ -887,7 +925,7 @@ get_verbose <- function(verbose = NULL) {
   }
 }
 
-.get_caller_call <- function(
+get_caller_call <- function(
     frame = parent.frame(),
     max_depth = 10) {
   if (is.null(frame)) {
@@ -898,12 +936,12 @@ get_verbose <- function(verbose = NULL) {
     {
       internal_functions <- c(
         "log_message",
-        ".validate_params",
-        ".output_message",
-        ".style_formatting",
-        ".check_color",
-        ".make_color_style",
-        ".extract_function_name"
+        "validate_params",
+        "output_message",
+        "style_formatting",
+        "check_color",
+        "make_color_style",
+        "extract_function_name"
       )
 
       calls <- sys.calls()
@@ -927,10 +965,10 @@ get_verbose <- function(verbose = NULL) {
           next
         }
 
-        fun_name <- .extract_function_name(call)
+        fun_name <- extract_function_name(call)
 
         if (!is.null(fun_name) && !fun_name %in% internal_functions) {
-          if (!identical(call[[1]], quote(.get_caller_call))) {
+          if (!identical(call[[1]], quote(get_caller_call))) {
             return(call)
           }
         }
@@ -944,7 +982,7 @@ get_verbose <- function(verbose = NULL) {
   )
 }
 
-.extract_function_name <- function(call) {
+extract_function_name <- function(call) {
   tryCatch(
     {
       fun_part <- call[[1]]
@@ -967,7 +1005,7 @@ get_verbose <- function(verbose = NULL) {
   )
 }
 
-.make_color_style <- function(color, bg = FALSE) {
+make_color_style <- function(color, bg = FALSE) {
   if (!bg) {
     text_color_map <- list(
       "black" = cli::col_black,
@@ -1023,7 +1061,7 @@ get_verbose <- function(verbose = NULL) {
   return(cli::make_ansi_style(color, bg = bg))
 }
 
-.check_color <- function(color) {
+check_color <- function(color) {
   if (!is.character(color) || length(color) != 1) {
     return(FALSE)
   }
